const emojiDictionary = {
    'happy': '😊',
    'sad': '😢',
    'love': '❤️',
    'cat': '🐱',
    'dog': '🐶',
    'sun': '☀️',
    'moon': '🌙',
    'star': '⭐',
    'heart': '❤️',
    'smile': '😊',
    'laugh': '😂',
    'cry': '😭',
    'food': '🍔',
    'drink': '🥤',
    'sleep': '😴',
    'work': '💼',
    'home': '🏠',
    'phone': '📱',
    'music': '🎵',
    'book': '📚'
};

const synonyms = {
    'happy': ['joy', 'glad', 'cheerful', 'delighted'],
    'sad': ['unhappy', 'depressed', 'down', 'gloomy'],
    'love': ['adore', 'cherish', 'like'],
    'sleep': ['nap', 'rest', 'snooze'],
    'laugh': ['giggle', 'chuckle', 'lol']
};

document.getElementById('translateBtn').addEventListener('click', () => {
    const inputText = document.getElementById('inputText').value.trim();
    const lastTranslation = document.getElementById('outputText').textContent;

    if (!inputText) {
        showWarning('Please enter some text to translate.');
        return;
    }

    if (inputText === lastTranslation) {
        showWarning('Text is unchanged from last translation.');
        return;
    }

    const translation = translateText(inputText);
    document.getElementById('outputText').textContent = translation;
});

document.getElementById('clearBtn').addEventListener('click', () => {
    document.getElementById('inputText').value = '';
    document.getElementById('outputText').textContent = '';
});

function translateText(text) {
    const words = text.toLowerCase().split(/\b/);
    return words.map(word => {
        const trimmedWord = word.trim();
        if (!trimmedWord) return word;

        // Check direct matches
        if (emojiDictionary[trimmedWord]) {
            return emojiDictionary[trimmedWord];
        }

        // Check synonyms
        for (const [key, synonymList] of Object.entries(synonyms)) {
            if (synonymList.includes(trimmedWord)) {
                return emojiDictionary[key];
            }
        }

        return word;
    }).join('');
}

function showWarning(message) {
    const warning = document.createElement('div');
    warning.className = 'warning';
    warning.textContent = message;
    warning.style.cssText = `
        position: fixed;
        top: 20px;
        right: 20px;
        background: #ff6b6b;
        color: white;
        padding: 1rem;
        border-radius: 8px;
        animation: slideIn 0.3s ease;
    `;

    document.body.appendChild(warning);

    setTimeout(() => {
        warning.style.animation = 'slideOut 0.3s ease';
        setTimeout(() => warning.remove(), 300);
    }, 3000);
}